@@ -30,20 +30,6 @@ from ceilometerclient import exc
 from ceilometerclient.openstack.common import cliutils
 
 
-def _positive_non_zero_int(argument_value):
-    if argument_value is None:
-        return None
-    try:
-        value = int(argument_value)
-    except ValueError:
-        msg = "%s must be an integer" % argument_value
-        raise argparse.ArgumentTypeError(msg)
-    if value <= 0:
-        msg = "%s must be greater than 0" % argument_value
-        raise argparse.ArgumentTypeError(msg)
-    return value
-
-
 class CeilometerShell(object):
 
     def get_base_parser(self):
@@ -78,17 +64,13 @@ class CeilometerShell(object):
 
         parser.add_argument('--timeout',
                             default=600,
-                            type=_positive_non_zero_int,
                             help='Number of seconds to wait for a response.')
 
-        parser.add_argument('--ceilometer-url', metavar='<CEILOMETER_URL>',
-                            dest='os_endpoint',
+        parser.add_argument('--ceilometer-url',
                             default=cliutils.env('CEILOMETER_URL'),
-                            help=("DEPRECATED, use --os-endpoint instead. "
-                                  "Defaults to env[CEILOMETER_URL]."))
+                            help='Defaults to env[CEILOMETER_URL].')
 
         parser.add_argument('--ceilometer_url',
-                            dest='os_endpoint',
                             help=argparse.SUPPRESS)
 
         parser.add_argument('--ceilometer-api-version',
@@ -146,8 +128,7 @@ class CeilometerShell(object):
                 subparser.add_argument(*args, **kwargs)
             subparser.set_defaults(func=callback)
 
-    @staticmethod
-    def _setup_logging(debug):
+    def _setup_logging(self, debug):
         format = '%(levelname)s (%(module)s) %(message)s'
         if debug:
             logging.basicConfig(format=format, level=logging.DEBUG)
@@ -158,7 +139,7 @@ class CeilometerShell(object):
 
     def parse_args(self, argv):
         # Parse args once to find version
-        self.auth_plugin = ceiloclient.AuthPlugin()
+        self.auth_plugin = ceiloclient.AuthPlugin(argv)
         parser = self.get_base_parser()
         (options, args) = parser.parse_known_args(argv)
         self.auth_plugin.parse_opts(options)
@@ -178,8 +159,7 @@ class CeilometerShell(object):
         # Return parsed args
         return api_version, subcommand_parser.parse_args(argv)
 
-    @staticmethod
-    def no_project_and_domain_set(args):
+    def no_project_and_domain_set(self, args):
         if not (args.os_project_id or (args.os_project_name and
                 (args.os_user_domain_name or args.os_user_domain_id)) or
                 (args.os_tenant_id or args.os_tenant_name)):
@@ -201,9 +181,7 @@ class CeilometerShell(object):
             self.do_bash_completion(args)
             return 0
 
-        if not ((self.auth_plugin.opts.get('token')
-                 or self.auth_plugin.opts.get('auth_token'))
-                and self.auth_plugin.opts['endpoint']):
+        if not (self.auth_plugin.opts['auth_token'] and args.ceilometer_url):
             if not self.auth_plugin.opts['username']:
                 raise exc.CommandError("You must provide a username via "
                                        "either --os-username or via "
@@ -240,7 +218,7 @@ class CeilometerShell(object):
         client_kwargs = vars(args)
         client_kwargs.update(self.auth_plugin.opts)
         client_kwargs['auth_plugin'] = self.auth_plugin
-        client = ceiloclient.get_client(api_version, **client_kwargs)
+        client = ceiloclient.Client(api_version, **client_kwargs)
         # call whatever callback was selected
         try:
             args.func(client, args)
@@ -302,9 +280,6 @@ def main(args=None):
         else:
             print(encodeutils.safe_encode(six.text_type(e)), file=sys.stderr)
         sys.exit(1)
-    except KeyboardInterrupt:
-        print("Stopping Ceilometer Client", file=sys.stderr)
-        sys.exit(130)
 
 if __name__ == "__main__":
     main()
